# captif-db-config

Database configuration.


## Config file

Place a `.captif-db.ini` file in the home directory (`~` on linux). The config file should contain the following information:

```
[GENERAL]
host =
port =
username = 
password = 
ssl_ca =
ssl_cert =
ssl_key =
```
